grib2io.tables.section4_discipline2 API documentation

# grib2io.tables.section4_discipline2

View Source

      1table_4_2_2_0  = {
      2'0':['Land Cover (0=sea, 1=land)','Proportion','LAND'],
      3'1':['Surface Roughness','m','SFCR'],
      4'2':['Soil Temperature','K','TSOIL'],
      5'3':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
      6'4':['Vegetation','%','VEG'],
      7'5':['Water Runoff','kg m-2','WATR'],
      8'6':['Evapotranspiration','kg-2 s-1','EVAPT'],
      9'7':['Model Terrain Height','m','MTERH'],
     10'8':['Land Use','See Table 4.212','LANDU'],
     11'9':['Volumetric Soil Moisture Content','Proportion','SOILW'],
     12'10':['Ground Heat Flux','W m-2','GFLUX'],
     13'11':['Moisture Availability','%','MSTAV'],
     14'12':['Exchange Coefficient','kg m-2 s-1','SFEXC'],
     15'13':['Plant Canopy Surface Water','kg m-2','CNWAT'],
     16'14':['Blackadars Mixing Length Scale','m','BMIXL'],
     17'15':['Canopy Conductance','m s-1','CCOND'],
     18'16':['Minimal Stomatal Resistance','s m-1','RSMIN'],
     19'17':['Wilting Point','Proportion','WILT'],
     20'18':['Solar parameter in canopy conductance','Proportion','RCS'],
     21'19':['Temperature parameter in canopy','Proportion','RCT'],
     22'20':['Humidity parameter in canopy conductance','Proportion','RCQ'],
     23'21':['Soil moisture parameter in canopy conductance','Proportion','RCSOL'],
     24'22':['Parameter deprecated - use another parameter instead.','unknown','unknown'],
     25'23':['Column-Integrated Soil Water','kg m-2','CISOILW'],
     26'24':['Heat Flux','W m-2','HFLUX'],
     27'25':['Volumetric Soil Moisture','m3 m-3','VSOILM'],
     28'26':['Wilting Point','kg m-3','WILT'],
     29'27':['Volumetric Wilting Point','m3 m-3','VWILTP'],
     30'28':['Leaf Area Index','Numeric','LEAINX'],
     31'29':['Evergreen Forest Cover','Proportion','EVGFC'],
     32'30':['Deciduous Forest Cover','Proportion','DECFC'],
     33'31':['Normalized Differential Vegetation Index (NDVI)','Numeric','NDVINX'],
     34'32':['Root Depth of Vegetation','m','RDVEG'],
     35'33':['Water Runoff and Drainage','kg m-2','WROD'],
     36'34':['Surface Water Runoff','kg m-2','SFCWRO'],
     37'35':['Tile Class','See Table 4.243','TCLASS'],
     38'36':['Tile Fraction','Proportion','TFRCT'],
     39'37':['Tile Percentage','%','TPERCT'],
     40'38':['Soil Volumetric Ice Content (Water Equivalent)','m3 m-3','SOILVIC'],
     41'39':['Evapotranspiration Rate','kg m-2 s-1','EVAPTRAT'],
     42'40':['Potential Evapotranspiration Rate','kg m-2 s-1','PERATE'],
     43'41':['Snow Melt Rate','kg m-2 s-1','SMRATE'],
     44'42':['Water Runoff and Drainage Rate','kg m-2 s-1','WRDRATE'],
     45'43':['Drainage direction','See Table 4.250','DRAINDIR'],
     46'44':['Upstream Area','m2','UPSAREA'],
     47'45-191':['Reserved','unknown','unknown'],
     48'192-254':['Reserved for Local Use','unknown','unknown'],
     49'192':['Volumetric Soil Moisture Content','Fraction','SOILW'],
     50'193':['Ground Heat Flux','W m-2','GFLUX'],
     51'194':['Moisture Availability','%','MSTAV'],
     52'195':['Exchange Coefficient','(kg m-3) (m s-1)','SFEXC'],
     53'196':['Plant Canopy Surface Water','kg m-2','CNWAT'],
     54'197':['Blackadar’s Mixing Length Scale','m','BMIXL'],
     55'198':['Vegetation Type','Integer (0-13)','VGTYP'],
     56'199':['Canopy Conductance','m s-1','CCOND'],
     57'200':['Minimal Stomatal Resistance','s m-1','RSMIN'],
     58'201':['Wilting Point','Fraction','WILT'],
     59'202':['Solar parameter in canopy conductance','Fraction','RCS'],
     60'203':['Temperature parameter in canopy conductance','Fraction','RCT'],
     61'204':['Humidity parameter in canopy conductance','Fraction','RCQ'],
     62'205':['Soil moisture parameter in canopy conductance','Fraction','RCSOL'],
     63'206':['Rate of water dropping from canopy to ground','unknown','RDRIP'],
     64'207':['Ice-free water surface','%','ICWAT'],
     65'208':['Surface exchange coefficients for T and Q divided by delta z','m s-1','AKHS'],
     66'209':['Surface exchange coefficients for U and V divided by delta z','m s-1','AKMS'],
     67'210':['Vegetation canopy temperature','K','VEGT'],
     68'211':['Surface water storage','Kg m-2','SSTOR'],
     69'212':['Liquid soil moisture content (non-frozen)','Kg m-2','LSOIL'],
     70'213':['Open water evaporation (standing water)','W m-2','EWATR'],
     71'214':['Groundwater recharge','Kg m-2','GWREC'],
     72'215':['Flood plain recharge','Kg m-2','QREC'],
     73'216':['Roughness length for heat','m','SFCRH'],
     74'217':['Normalized Difference Vegetation Index','unknown','NDVI'],
     75'218':['Land-sea coverage (nearest neighbor) [land=1,sea=0]','unknown','LANDN'],
     76'219':['Asymptotic mixing length scale','m','AMIXL'],
     77'220':['Water vapor added by precip assimilation','Kg m-2','WVINC'],
     78'221':['Water condensate added by precip assimilation','Kg m-2','WCINC'],
     79'222':['Water Vapor Flux Convergance (Vertical Int)','Kg m-2','WVCONV'],
     80'223':['Water Condensate Flux Convergance (Vertical Int)','Kg m-2','WCCONV'],
     81'224':['Water Vapor Zonal Flux (Vertical Int)','Kg m-2','WVUFLX'],
     82'225':['Water Vapor Meridional Flux (Vertical Int)','Kg m-2','WVVFLX'],
     83'226':['Water Condensate Zonal Flux (Vertical Int)','Kg m-2','WCUFLX'],
     84'227':['Water Condensate Meridional Flux (Vertical Int)','Kg m-2','WCVFLX'],
     85'228':['Aerodynamic conductance','m s-1','ACOND'],
     86'229':['Canopy water evaporation','W m-2','EVCW'],
     87'230':['Transpiration','W m-2','TRANS'],
     88'231':['Seasonally Minimum Green Vegetation Fraction (over 1-year period)','%','VEGMIN'],
     89'232':['Seasonally Maximum Green Vegetation Fraction (over 1-year period)','%','VEGMAX'],
     90'233':['Land Fraction','Fraction','LANDFRC'],
     91'234':['Lake Fraction','Fraction','LAKEFRC'],
     92'235':['Precipitation Advected Heat Flux','W m-2','PAHFLX'],
     93'236':['Water Storage in Aquifer','Kg m-2','WATERSA'],
     94'237':['Evaporation of Intercepted Water','Kg m-2','EIWATER'],
     95'238':['Plant Transpiration','Kg m-2','PLANTTR'],
     96'239':['Soil Surface Evaporation','Kg m-2','SOILSE'],
     97'255':['Missing','unknown','unknown'],
     98}
     99table_4_2_2_1  = {
    100'0-191':['Reserved','unknown','unknown'],
    101'192-254':['Reserved for Local Use','unknown','unknown'],
    102'192':['Cold Advisory for Newborn Livestock','unknown','CANL'],
    103'255':['Missing','unknown','unknown'],
    104}
    105table_4_2_2_3  = {
    106'0':['Soil Type','See Table 4.213','SOTYP'],
    107'1':['Upper Layer Soil Temperature','K','UPLST'],
    108'2':['Upper Layer Soil Moisture','kg m-3','UPLSM'],
    109'3':['Lower Layer Soil Moisture','kg m-3','LOWLSM'],
    110'4':['Bottom Layer Soil Temperature','K','BOTLST'],
    111'5':['Liquid Volumetric Soil Moisture (non-frozen)','Proportion','SOILL'],
    112'6':['Number of Soil Layers in Root Zone','Numeric','RLYRS'],
    113'7':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
    114'8':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
    115'9':['Soil Porosity','Proportion','POROS'],
    116'10':['Liquid Volumetric Soil Moisture (Non-Frozen)','m3 m-3','LIQVSM'],
    117'11':['Volumetric Transpiration Stree-Onset(Soil Moisture)','m3 m-3','VOLTSO'],
    118'12':['Transpiration Stree-Onset(Soil Moisture)','kg m-3','TRANSO'],
    119'13':['Volumetric Direct Evaporation Cease(Soil Moisture)','m3 m-3','VOLDEC'],
    120'14':['Direct Evaporation Cease(Soil Moisture)','kg m-3','DIREC'],
    121'15':['Soil Porosity','m3 m-3','SOILP'],
    122'16':['Volumetric Saturation Of Soil Moisture','m3 m-3','VSOSM'],
    123'17':['Saturation Of Soil Moisture','kg m-3','SATOSM'],
    124'18':['Soil Temperature','K','SOILTMP'],
    125'19':['Soil Moisture','kg m-3','SOILMOI'],
    126'20':['Column-Integrated Soil Moisture','kg m-2','CISOILM'],
    127'21':['Soil Ice','kg m-3','SOILICE'],
    128'22':['Column-Integrated Soil Ice','kg m-2','CISICE'],
    129'23':['Liquid Water in Snow Pack','kg m-2','LWSNWP'],
    130'24':['Frost Index','kg day-1','FRSTINX'],
    131'25':['Snow Depth at Elevation Bands','kg m-2','SNWDEB'],
    132'26':['Soil Heat Flux','W m-2','SHFLX'],
    133'27':['Soil Depth','m','SOILDEP'],
    134'28':['Snow Temperature','K','SNOWTMP'],
    135'29':['Ice Temperature','K','ICETEMP'],
    136'30-191':['Reserved','unknown','unknown'],
    137'192-254':['Reserved for Local Use','unknown','unknown'],
    138'192':['Liquid Volumetric Soil Moisture (non Frozen)','Proportion','SOILL'],
    139'193':['Number of Soil Layers in Root Zone','non-dim','RLYRS'],
    140'194':['Surface Slope Type','Index','SLTYP'],
    141'195':['Transpiration Stress-onset (soil moisture)','Proportion','SMREF'],
    142'196':['Direct Evaporation Cease (soil moisture)','Proportion','SMDRY'],
    143'197':['Soil Porosity','Proportion','POROS'],
    144'198':['Direct Evaporation from Bare Soil','W m-2','EVBS'],
    145'199':['Land Surface Precipitation Accumulation','kg m-2','LSPA'],
    146'200':['Bare Soil Surface Skin temperature','K','BARET'],
    147'201':['Average Surface Skin Temperature','K','AVSFT'],
    148'202':['Effective Radiative Skin Temperature','K','RADT'],
    149'203':['Field Capacity','Fraction','FLDCP'],
    150'204':['Soil Moisture Availability In The Top Soil Layer','%','MSTAV'],
    151'255':['Missing','unknown','unknown'],
    152}
    153table_4_2_2_4  = {
    154'0':['Fire Outlook','See Table 4.224','FIREOLK'],
    155'1':['Fire Outlook Due to Dry Thunderstorm','See Table 4.224','FIREODT'],
    156'2':['Haines Index','Numeric','HINDEX'],
    157'3':['Fire Burned Area','%','FBAREA'],
    158'4':['Fosberg Index','Numeric','FOSINDX'],
    159'5':['Fire Weath Index (Canadian Forest Service)','Numeric','FWINX'],
    160'6':['Fine Fuel Moisture Code (Canadian Forest Service)','Numeric','FFMCODE'],
    161'7':['Duff Moisture Code (Canadian Forest Service)','Numeric','DUFMCODE'],
    162'8':['Drought Code (Canadian Forest Service)','Numeric','DRTCODE'],
    163'9':['Initial Fire Spread Index (Canadian Forest Service)','Numeric','INFSINX'],
    164'10':['Fire Build Up Index (Canadian Forest Service)','Numeric','FBUPINX'],
    165'11':['Fire Daily Severity Rating (Canadian Forest Service)','Numeric','FDSRTE'],
    166'12':['Keetch-Byram Drought Index','Numeric','KRIDX'],
    167'13':['Drought Factor (as defined by the Australian forest service)','Numeric','DRFACT'],
    168'14':['Rate of Spread (as defined by the Australian forest service)','m s-1','RATESPRD'],
    169'15':['Fire Danger index (as defined by the Australian forest service)','Numeric','FIREDIDX'],
    170'16':['Spread component (as defined by the US Forest Service National Fire Danger Rating System)','Numeric','DRFACT'],
    171'17':['Burning Index (as defined by the Australian forest service)','Numeric','SPRDCOMP'],
    172'18':['Ignition Component (as defined by the Australian forest service)','%','IGNCOMP'],
    173'19':['Energy Release Component (as defined by the Australian forest service)','J m-2','ENRELCOM'],
    174'20-191':['Reserved','unknown','unknown'],
    175'192-254':['Reserved for Local Use','unknown','unknown'],
    176'255':['Missing','unknown','unknown'],
    177}
    178table_4_2_2_5  = {
    179'0':['Glacier Cover (see Note)','Proportion','GLACCOV'],
    180'1':['Glacier Temperature','K','GLACTMP'],
    181'2-191':['Reserved','unknown','unknown'],
    182'192-254':['Reserved for Local Use','unknown','unknown'],
    183'255':['Missing','unknown','unknown'],
    184}